==============
SeismicMesh
==============

:Author:  Keith Jared Roberts
:Contact: keithrbt0@gmail.com


Online Documentation
--------------------

Hosted at *Read the Docs* [http://SeismicMesh.readthedocs.org/]:

.. image::  https://readthedocs.org/projects/SeismicMesh/badge/?version=stable
   :target: https://SeismicMesh.readthedocs.org/en/stable/
.. image::  https://readthedocs.org/projects/SeismicMesh/badge/?version=latest
   :target: https://SeismicMesh.readthedocs.org/en/latest/

Hosted at *Github* [https://github/krober10nd/SeismicMesh]:

+ `User Manual (HTML)`_ (generated with Sphinx_).
+ `User Manual (PDF)`_  (generated with Sphinx_).
+ `API Reference`_      (generated with Epydoc_).

.. _User Manual (HTML): usrman/index.html
.. _User Manual (PDF):  SeismicMesh.pdf
.. _API Reference:      apiref/index.html

.. _Sphinx: http://sphinx-doc.org/
.. _Epydoc: http://epydoc.sourceforge.net/


Discussion and Support
----------------------

Hosted at Google Groups:

+ Group Page:   http://groups.google.com/group/SeismicMesh
+ Mailing List: SeismicMesh@googlegroups.com


Downloads and Development
-------------------------

Hosted at Github:

+ Project Site:    https://github.org/krober10nd/SeismicMesh
+ Source Releases: https://github.org/krober10nd/SeismicMesh/downloads
+ Issue Tracker:   https://github.org/krober10nd/SeismicMesh/issues
+ Git Repository:  https://github.org/krober10nd/SeismicMesh.git


Citations
---------

+ K.J. Roberts
  *SeismicMesh*
  to be submitted to Journal of Open Source Software (JOSS)


Acknowledgments
---------------

This project was supported by...
